
# Version 1.2.0

+ Fix bugs in `seed` value, `OneHotEncoder` class, and `hard_shrink` function.
+ Update `trainer` parameter for model
+ Rename `list_methods` parameter to `list_metrics` parameter
+ Update examples, tests, and documentation.

------------------------------------------------------------------------------

# Version 1.1.0

+ Rename `MhaTuneRvfl` class to `GfoRvflTuner` class
+ Add seed parameter to all classes.
+ Add examples with GridSearchCV
+ Update PerMetrics and Mealpy dependencies
+ Update documents

------------------------------------------------------------------------------

# Version 1.0.0 (First version)

+ This library uses Numpy only - Gradient Free (No Pytorch, No Tensorflow)
+ Add infors (CODE_OF_CONDUCT.md, MANIFEST.in, LICENSE, requirements.txt)
+ Add shared modules (activator, boundary_controller, data_processor, randomer, scaler, and scorer)
+ Add `RvflRegressor` and `RvflClassifier` classes
+ Add `GfoRvflTuner` class that can be used to tune RVFL network
+ Add publish workflow
+ Add examples and tests folders

------------------------------------------------------------------------------

# Version 0.0.1

+ Test version to get Zonodo DOI
